pub struct ModalityParser {}Implementations
Sourceimpl ModalityParser
impl ModalityParser
pub fn new() -> ModalityParser
Sourcepub fn parse_model(&self, content: &str) -> Result<JsValue, JsValue>
pub fn parse_model(&self, content: &str) -> Result<JsValue, JsValue>
Parse a model from a string
Sourcepub fn parse_all_models(&self, content: &str) -> Result<JsValue, JsValue>
pub fn parse_all_models(&self, content: &str) -> Result<JsValue, JsValue>
Parse all models from a string
Sourcepub fn generate_mermaid(&self, model_json: &str) -> Result<String, JsValue>
pub fn generate_mermaid(&self, model_json: &str) -> Result<String, JsValue>
Generate Mermaid diagram from a model JSON string
Sourcepub fn generate_mermaid_styled(
&self,
model_json: &str,
) -> Result<String, JsValue>
pub fn generate_mermaid_styled( &self, model_json: &str, ) -> Result<String, JsValue>
Generate Mermaid diagram with styling from a model JSON string
Sourcepub fn generate_mermaid_with_state(
&self,
model_json: &str,
) -> Result<String, JsValue>
pub fn generate_mermaid_with_state( &self, model_json: &str, ) -> Result<String, JsValue>
Generate Mermaid diagram with current state highlighting from a model JSON string
Sourcepub fn parse_formulas(&self, content: &str) -> Result<JsValue, JsValue>
pub fn parse_formulas(&self, content: &str) -> Result<JsValue, JsValue>
Parse formulas from a string